<?php

/**
 * This function allow get property of `woocommerce_loop` inside the loop
 * @since 1.0.4
 * @param string $prop Prop to get.
 * @param string $default Default if the prop does not exist.
 * @return mixed
 */

if(!function_exists('la_zyra_get_wc_loop_prop')){
    function la_zyra_get_wc_loop_prop( $prop, $default = ''){
        return isset( $GLOBALS['woocommerce_loop'], $GLOBALS['woocommerce_loop'][ $prop ] ) ? $GLOBALS['woocommerce_loop'][ $prop ] : $default;
    }
}

/**
 * This function allow set property of `woocommerce_loop`
 * @since 1.0.4
 * @param string $prop Prop to set.
 * @param string $value Value to set.
 */

if(!function_exists('la_zyra_set_wc_loop_prop')){
    function la_zyra_set_wc_loop_prop( $prop, $value = ''){
        if(isset($GLOBALS['woocommerce_loop'])){
            $GLOBALS['woocommerce_loop'][ $prop ] = $value;
        }
    }
}

/**
 * This function allow get property of `la_zyra_loop` inside the loop
 * @since 1.0.4
 * @param string $prop Prop to get.
 * @param string $default Default if the prop does not exist.
 * @return mixed
 */

if(!function_exists('la_zyra_get_theme_loop_prop')){
    function la_zyra_get_theme_loop_prop( $prop, $default = ''){
        return isset( $GLOBALS['la_zyra_loop'], $GLOBALS['la_zyra_loop'][ $prop ] ) ? $GLOBALS['la_zyra_loop'][ $prop ] : $default;
    }
}

/**
 * This function allow set property of `la_zyra_loop`
 * @since 1.0.4
 * @param string $prop Prop to set.
 * @param string $value Value to set.
 */

if(!function_exists('la_zyra_set_theme_loop_prop')){
    function la_zyra_set_theme_loop_prop( $prop, $value = ''){
        if(!isset($GLOBALS['la_zyra_loop'])){
            $GLOBALS['la_zyra_loop'] = array();
        }
        $GLOBALS['la_zyra_loop'][ $prop ] = $value;
    }
}


remove_filter( 'woocommerce_product_loop_start', 'woocommerce_maybe_show_product_subcategories' );


if(!function_exists('la_zyra_add_ajax_cart_btn_into_single_product')){
    function la_zyra_add_ajax_cart_btn_into_single_product(){
        global $product;
        if($product->is_type('simple')){
            echo '<div class="wrap-single-addcart hidden">';
            woocommerce_template_loop_add_to_cart();
            echo '</div>';
        }
    }
    add_action('woocommerce_after_add_to_cart_button', 'la_zyra_add_ajax_cart_btn_into_single_product');
}


/**
 * This function allow to display correct product thumbail size
 * @since 1.0.8
 */
if(!function_exists('la_zyra_override_woothumbnail_size')){
    function la_zyra_override_woothumbnail_size( $size ) {
        if(!function_exists('wc_get_theme_support')){
            return $size;
        }
        $size['width'] = absint( wc_get_theme_support( 'gallery_thumbnail_image_width', 100 ) );
        $cropping      = get_option( 'woocommerce_thumbnail_cropping', '1:1' );

        if ( 'uncropped' === $cropping ) {
            $size['height'] = 0;
            $size['crop']   = 0;
        }
        elseif ( 'custom' === $cropping ) {
            $width          = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_width', '4' ) );
            $height         = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_height', '3' ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }
        else {
            $cropping_split = explode( ':', $cropping );
            $width          = max( 1, current( $cropping_split ) );
            $height         = max( 1, end( $cropping_split ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }

        return $size;
    }
    add_filter('woocommerce_get_image_size_gallery_thumbnail', 'la_zyra_override_woothumbnail_size');
}

/**
 * strip all the shortcode on the raw terms and conditions on the checkout page
 * @since 1.0.8
 */
if(!function_exists('la_zyra_override_filter_woocommerce_format_content')){
    function la_zyra_override_filter_woocommerce_format_content( $format, $raw_string ){
        $format = preg_replace("~(?:\[/?)[^/\]]+/?\]~s", '', $raw_string);
        return apply_filters( 'woocommerce_short_description', $format );
    }
    add_filter('woocommerce_format_content', 'la_zyra_override_filter_woocommerce_format_content', 99, 2);
}

/**
 * Check if has products in the loop
 * @since 1.0.8
 */
if(!function_exists('la_zyra_wc_product_loop')){
    function la_zyra_wc_product_loop(){
        if(!function_exists('WC')){
            return false;
        }
        return have_posts() || 'products' !== woocommerce_get_loop_display_mode();
    }
}


/**
 * This function allow to display correct product single image
 * @since 1.1.0
 */

if(!function_exists('la_zyra_override_woothumbnail_single')){
    function la_zyra_override_woothumbnail_single( $size ) {
        if(!function_exists('wc_get_theme_support')){
            return $size;
        }
        $size['width'] = absint( wc_get_theme_support( 'single_image_width', get_option( 'woocommerce_single_image_width', 600 ) ) );
        $cropping      = get_option( 'woocommerce_thumbnail_cropping', '1:1' );

        if ( 'uncropped' === $cropping ) {
            $size['height'] = 0;
            $size['crop']   = 0;
        }
        elseif ( 'custom' === $cropping ) {
            $width          = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_width', '4' ) );
            $height         = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_height', '3' ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }
        else {
            $cropping_split = explode( ':', $cropping );
            $width          = max( 1, current( $cropping_split ) );
            $height         = max( 1, end( $cropping_split ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }

        return $size;
    }
    add_filter('woocommerce_get_image_size_single', 'la_zyra_override_woothumbnail_single', 0);
}

add_filter('pre_option_site_icon', function (){
    return 0;
});

add_action( 'wp_ajax_lastudio_ig_feed', 'la_zyra_ajax_get_ig_feed' );
add_action( 'wp_ajax_nopriv_lastudio_ig_feed', 'la_zyra_ajax_get_ig_feed' );

if(!function_exists('la_zyra_ajax_get_ig_feed')){
    function la_zyra_ajax_get_ig_feed(){
        // check token first;
        $token = LA_Zyra()->settings->get('instagram_token', '');
        if(empty($token)){
            wp_send_json_error(['msg' => __('Invalid Token', 'la-zyra')]);
        }
        $life_time = get_transient('lastudio_ig_token');
        if(empty($life_time)){
            $ig_refresh_token_url = add_query_arg([
                'grant_type' => 'ig_refresh_token',
                'access_token' => $token
            ], 'https://graph.instagram.com/refresh_access_token');
            $response = wp_remote_get($ig_refresh_token_url);
            // request failed
            if ( is_wp_error( $response ) ) {
                wp_send_json_error(['msg' => __('Invalid Token [1]', 'la-zyra')]);
            }
            $code = (int) wp_remote_retrieve_response_code( $response );
            if ( $code !== 200 ) {
                wp_send_json_error(['msg' => __('Invalid Token [2]', 'la-zyra')]);
            }
            $body = wp_remote_retrieve_body($response);
            $body = json_decode($body, true);
            $expires_in = (int) $body['expires_in'] - DAY_IN_SECONDS;
            if($expires_in > 0){
                $token = $body['access_token'];
                $all_option = get_option(LA_Zyra::get_option_name(), []);
                $all_option['instagram_token'] = $token;
                update_option(LA_Zyra::get_option_name(), $all_option);
                set_transient('lastudio_ig_token', $body , $expires_in);
            }
            else{
                wp_send_json_error(['msg' => __('Token Expired [3]', 'la-zyra')]);
            }
        }

        $cache = get_transient('lastudio_ig_feed');
        if(empty($cache)){
            $ig_feed_url = add_query_arg([
                'fields'        => 'caption,media_type,media_url,thumbnail_url,permalink,timestamp',
                'access_token'  => $token,
                'limit'         => 20
            ], 'https://graph.instagram.com/me/media');

            $response = wp_remote_get($ig_feed_url);
            if ( is_wp_error( $response ) ) {
                wp_send_json_error(['msg' => __('Invalid Token [4]', 'la-zyra')]);
            }
            $code = (int) wp_remote_retrieve_response_code( $response );
            if ( $code !== 200 ) {
                wp_send_json_error(['msg' => __('Invalid Token [5]', 'la-zyra')]);
            }
            $data = wp_remote_retrieve_body($response);
            $data = json_decode($data, true);
            $cache = $data['data'];
            set_transient('lastudio_ig_feed', $cache, HOUR_IN_SECONDS * 12);
        }
        if(empty($cache)){
            wp_send_json_error(['msg' => __('Invalid Token [6]', 'la-zyra')]);
        }
        else{
            wp_send_json_success($cache);
        }
    }
}